@@ -9,9 +9,13 @@ use Aspect::Advice;
 use Aspect::Pointcut::Call;
 use Aspect::Pointcut::Cflow;
 
+
+our $VERSION = '0.13';
+
+
 use base 'Exporter';
 
-our $VERSION = '0.11';
+
 our @EXPORT  = qw(aspect before after call cflow);
 
 my (@Aspect_Store, @Advice_Store);
@@ -45,8 +49,12 @@ sub runtime_use {
 	croak "Cannot use [$package]: $@" if $@;
 }
 
+
 1;
 
+
+__END__
+
 =head1 NAME
 
 Aspect - AOP for Perl
@@ -440,25 +448,40 @@ solution is to narrow the pointcut:
 
 See the C<TODO> file in the distribution for possible solutions.
 
-=head1 BUGS
-
-None known so far. If you find any bugs or oddities, please do inform the
-maintainer.
-
-=head1 AUTHOR
-
-Marcel GrE<uuml>nauer <marcel@cpan.org>, Ran Eilam <eilara@cpan.org>.
-
-=head1 COPYRIGHT
-
-Copyright 2001-2002 Marcel GrE<uuml>nauer. All rights reserved.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 SEE ALSO
 
 You can find AOP examples in the C<examples/> directory of the
 distribution.
 
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
+site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+
+=head1 AUTHORS
+
+Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+
+Ran Eilam C<< <eilara@cpan.org> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2001 by Marcel GrE<uuml>nauer
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
 =cut
+
