@@ -6,7 +6,9 @@ use Carp;
 use Aspect::AdviceContext;
 use Aspect::Weaver;
 
-our $VERSION = '0.10';
+
+our $VERSION = '0.13';
+
 
 sub new {
 	my ($class, $type, $code, $pointcut) = @_;
@@ -87,6 +89,8 @@ sub pointcut { shift->{pointcut} }
 
 1;
 
+__END__
+
 =head1 NAME
 
 Aspect::Advice - change how Perl code is run at a pointcut
@@ -128,4 +132,35 @@ need them.
 
 See the L<Aspect|::Aspect> pod for a guide to the Aspect module.
 
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
+site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+
+=head1 AUTHORS
+
+Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+
+Ran Eilam C<< <eilara@cpan.org> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2001 by Marcel GrE<uuml>nauer
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
 =cut
+
