@@ -6,6 +6,10 @@ use Carp;
 use Test::Class;
 use Aspect;
 
+
+our $VERSION = '0.13';
+
+
 use base 'Aspect::Modular';
 
 sub Test::Class::make_subject { shift->subject_class->new(@_) }
@@ -39,6 +43,10 @@ sub is_test_method_with_subject {
 
 1;
 
+__END__
+
+{% USE p = PodGenerated %}
+
 =head1 NAME
 
 Aspect::Library::TestClass - give Test::Class test methods an IUT
@@ -78,10 +86,45 @@ class of the IUT:
 
   sub subject_class { 'MyApp::Person' }
 
+=head1 REQUIRES
+
+Only works with C<Test::Class> above version C<0.06_05>.
+  
 =head1 SEE ALSO
 
 See the L<Aspect|::Aspect> pods for a guide to the Aspect module.
 
 C<XUL-Node> tests use this aspect extensively.
 
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
+site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+
+=head1 AUTHORS
+
+Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+
+Ran Eilam C<< <eilara@cpan.org> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2001 by Marcel GrE<uuml>nauer
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
 =cut
+
