@@ -2,34 +2,26 @@ package Aspect::Library::Wormhole;
 
 use strict;
 use warnings;
-use Aspect::Modular         ();
-use Aspect::Advice::Before  ();
-use Aspect::Pointcut::And   ();
-use Aspect::Pointcut::Call  ();
-use Aspect::Pointcut::Cflow ();
+use Carp;
+use Aspect;
 
-our $VERSION = '0.97_06';
-our @ISA     = 'Aspect::Modular';
+
+our $VERSION = '0.13';
+
+
+use base 'Aspect::Modular';
 
 sub get_advice {
-	my $self = shift;
-	Aspect::Advice::Before->new(
-		lexical  => $self->lexical,
-		pointcut => Aspect::Pointcut::And->new(
-			Aspect::Pointcut::Call->new( $_[1] ),
-			Aspect::Pointcut::Cflow->new( source => $_[0] ),
-		),
-		code => sub {
-			$_->args( $_->args, $_->source->self );
-		},
-	);
+	my ($self, $source, $target) = @_;
+	before { my $c = shift; $c->append_param($c->source->self) }
+		call $target & cflow source => $source;
 }
 
 1;
 
 __END__
 
-=pod
+{% USE p = PodGenerated %}
 
 =head1 NAME
 
@@ -40,23 +32,27 @@ Aspect::Library::Wormhole - A wormhole between call frames
   package A;
   sub new { bless {}, shift }
   sub a { B->new->b }
-  
+
   package B;
   sub new { bless {}, shift }
   sub b { C->new->c }
-  
+
   package C;
   sub new { bless {}, shift }
   sub c { ref pop }
-  
+
   package main;
-  
+
   print ref A->new->a; # without aspect, prints C
-  
+
   use Aspect::Library::Wormhole;
   aspect Wormhole => 'A::a', 'C::c';
   print ref A->new->a; # with aspect, prints A
 
+=head1 SUPER
+
+L<Aspect::Modular>
+
 =head1 DESCRIPTION
 
 A reusable aspect for passing objects down a call flow, without adding
@@ -126,21 +122,42 @@ defined on C<Page>, if it is in the call flow of C<Printer::print>:
 
   aspect Wormhole => 'Printer::Print', qr/^Page::/;
 
+=head1 SEE ALSO
+
+See the L<Aspect|::Aspect> pods for a guide to the Aspect module.
+
+You can find an example comparing the OO and AOP solutions in the
+C<examples/> directory of the distribution.
+
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
+site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+
 =head1 AUTHORS
 
-Adam Kennedy E<lt>adamk@cpan.orgE<gt>
+Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
-Marcel GrE<uuml>nauer E<lt>marcel@cpan.orgE<gt>
+Ran Eilam C<< <eilara@cpan.org> >>
 
-Ran Eilam E<lt>eilara@cpan.orgE<gt>
-
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
 Copyright 2001 by Marcel GrE<uuml>nauer
 
-Some parts copyright 2009 - 2011 Adam Kennedy.
-
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =cut
+
