@@ -4,7 +4,9 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.10';
+
+our $VERSION = '0.13';
+
 
 # creating --------------------------------------------------------------------
 
@@ -20,6 +22,10 @@ sub get_advice {}
 
 1;
 
+__END__
+
+{% USE p = PodGenerated %}
+
 =head1 NAME
 
 Aspect::Modular - base class for reusable aspects
@@ -66,7 +72,7 @@ interpreter shutdown.
 
 Typical things a reusable aspect may want to do:
 
-=over4
+=over 4
 
 =item *
 
@@ -86,6 +92,35 @@ See the L<Aspect|::Aspect> pod for a guide to the Aspect module.
 You can find examples of reusable aspects in the C<Aspect::Library>
 package. L<Aspect::Library::Singleton> for example.
 
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org>.
+
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
+site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+
+=head1 AUTHORS
+
+Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+
+Ran Eilam C<< <eilara@cpan.org> >>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2001 by Marcel GrE<uuml>nauer
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
 =cut
 
-
